@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 import sys
 import os
@@ -11,8 +11,11 @@ import shutil
 sys.path.insert(0,'/usr/lib/cinnamon-menu-editor')
 from cme import util
 
+sys.path.insert(0,'/usr/lib/cinnamon-settings')
+from bin import XletSettingsWidgets
+
 # i18n
-gettext.install("cinnamon", "/usr/share/cinnamon/locale")
+gettext.install("cinnamon", "/usr/share/locale")
 # i18n for menu item
 
 _ = gettext.gettext
@@ -50,11 +53,11 @@ def try_icon_name(filename):
     return parts[3]
 
 def get_icon_string(image):
-    filename = image.props.file
+    filename = image._file
     if filename is not None:
         return try_icon_name(filename)
 
-    return image.props.icon_name
+    return image._icon_name
 
 def strip_extensions(icon):
     if icon.endswith(EXTENSIONS):
@@ -64,9 +67,13 @@ def strip_extensions(icon):
 
 def set_icon_string(image, icon):
     if GLib.path_is_absolute(icon):
-        image.props.file = icon
+        image._file = icon
+        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(icon, 64, 64)
+        if pixbuf is not None:
+            image.set_from_pixbuf(pixbuf)
     else:
-        image.props.icon_name = strip_extensions(icon)
+        image._icon_name = strip_extensions(icon)
+        image.set_from_icon_name (strip_extensions (icon), Gtk.IconSize.BUTTON)
 
 def ask(msg):
     dialog = Gtk.MessageDialog(None,
@@ -99,14 +106,15 @@ class IconPicker(object):
         chooser.add_shortcut_folder("/usr/share/pixmaps")
         chooser.add_shortcut_folder("/usr/share/icons")
         fn = get_icon_string(self.image)
-        if GLib.path_is_absolute(fn):
-            chooser.set_filename(fn)
-        else:
-            theme = Gtk.IconTheme.get_default()
-            icon_info = theme.lookup_icon(fn, 64, 0)
-            icon_info_fn = icon_info.get_filename() if icon_info != None else None
-            if icon_info_fn:
-                chooser.set_filename(icon_info_fn)
+        if fn:
+            if GLib.path_is_absolute(fn):
+                chooser.set_filename(fn)
+            else:
+                theme = Gtk.IconTheme.get_default()
+                icon_info = theme.lookup_icon(fn, 64, 0)
+                icon_info_fn = icon_info.get_filename() if icon_info != None else None
+                if icon_info_fn:
+                    chooser.set_filename(icon_info_fn)
         filter = Gtk.FileFilter();
         filter.add_pixbuf_formats ();
         chooser.set_filter(filter);
@@ -117,7 +125,7 @@ class IconPicker(object):
 
         response = chooser.run()
         if response == Gtk.ResponseType.ACCEPT:
-            self.image.props.file = chooser.get_filename()
+            set_icon_string (self.image, chooser.get_filename())
         chooser.destroy()
 
     def update_icon_preview_cb(self, chooser, preview):
@@ -143,6 +151,10 @@ class ItemEditor(object):
 
         self.dialog.connect('response', self.on_response)
 
+        icon = self.builder.get_object('icon-image')
+        icon._file = None
+        icon._icon_name = None
+
         self.build_ui()
 
         self.item_path = item_path
@@ -160,20 +172,20 @@ class ItemEditor(object):
         if name_valid:
             self.builder.get_object('name-entry').set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, 'ok')
             self.builder.get_object('name-entry').set_icon_tooltip_text(Gtk.EntryIconPosition.SECONDARY,
-                                                                        _("Valid"))
+                                                                        _("Valid name"))
         else:
             self.builder.get_object('name-entry').set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, 'stop')
             self.builder.get_object('name-entry').set_icon_tooltip_text(Gtk.EntryIconPosition.SECONDARY,
-                                                                        _("Name cannot be blank."))
+                                                                        _("The name cannot be empty."))
 
         if exec_valid:
             self.builder.get_object('exec-entry').set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, 'ok')
             self.builder.get_object('exec-entry').set_icon_tooltip_text(Gtk.EntryIconPosition.SECONDARY,
-                                                                        _("Valid"))
+                                                                        _("Valid executable"))
         else:
             self.builder.get_object('exec-entry').set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY, 'stop')
             self.builder.get_object('exec-entry').set_icon_tooltip_text(Gtk.EntryIconPosition.SECONDARY,
-                                                                        _("Cannot be empty.  Spaces in filenames must be escaped with backslash (\\).\nNot a valid executable line."))
+                                                                        _("The executable is not valid. It cannot be empty and spaces in the path must be escaped with backslash (\\)."))
 
         self.builder.get_object('ok').set_sensitive(name_valid and exec_valid)
 
@@ -331,7 +343,7 @@ class DirectoryEditor(ItemEditor):
         pass
 
 
-class PanelLauncherEditor(ItemEditor):
+class CinnamonLauncherEditor(ItemEditor):
     ui_file = '/usr/lib/cinnamon-desktop-editor/launcher-editor.ui'
 
     def build_ui(self):
@@ -367,7 +379,7 @@ class PanelLauncherEditor(ItemEditor):
         self.sync_widgets(name_valid, exec_valid)
 
     def load(self):
-        super(PanelLauncherEditor, self).load()
+        super(CinnamonLauncherEditor, self).load()
         self.set_text('name-entry', "Name")
         self.set_text('exec-entry', "Exec")
         self.set_text('comment-entry', "Comment")
@@ -407,6 +419,9 @@ class Main:
             parser.error("directory and launcher modes must be accompanied by the -o argument")
         if options.mode == "nemo-launcher" and not options.destination_directory:
             parser.error("nemo-launcher mode must be accompanied by the -d argument")
+        if options.mode == "cinnamon-launcher" and len(args) < 3:
+            parser.error("cinnamon-launcher mode must have the following syntax:\n\
+                         cinnamon-desktop-editor -mcinnamon-launcher [-ffoo.desktop] <uuid> <instance-id> <json-path>")
 
         self.tree = CMenu.Tree.new("cinnamon-applications.menu", CMenu.TreeFlags.INCLUDE_NODISPLAY)
         if not self.tree.load_sync():
@@ -416,6 +431,12 @@ class Main:
         self.orig_file = options.original_desktop_file
         self.desktop_file = options.desktop_file
         self.dest_dir = options.destination_directory
+
+        if options.mode == "cinnamon-launcher":
+            self.uuid = args[0]
+            self.iid = args[1]
+            self.json_path = args[2]
+
         if self.desktop_file is not None:
             self.get_desktop_path()
 
@@ -425,8 +446,8 @@ class Main:
         elif self.mode == "launcher":
             editor = LauncherEditor(self.orig_file, self.launcher_cb)
             editor.dialog.show_all()
-        elif self.mode == "panel-launcher":
-            editor = PanelLauncherEditor(self.orig_file, self.panel_launcher_cb)
+        elif self.mode == "cinnamon-launcher":
+            editor = CinnamonLauncherEditor(self.orig_file, self.panel_launcher_cb)
             editor.dialog.show_all()
         elif self.mode == "nemo-launcher":
             editor = LauncherEditor(self.orig_file, self.nemo_launcher_cb, self.dest_dir)
@@ -442,8 +463,9 @@ class Main:
 
     def panel_launcher_cb(self, success, dest_path):
         if success:
-            settings = Gio.Settings.new("org.cinnamon")
-            launchers = settings.get_strv("panel-launchers")
+            factory = XletSettingsWidgets.Factory(self.json_path, self.iid, False, self.uuid)
+
+            launchers = factory.settings.get_value("launcherList")
             if self.desktop_file is None:
                 launchers.append(os.path.split(dest_path)[1])
             else:
@@ -451,7 +473,7 @@ class Main:
                 if i >= 0:
                     del launchers[i]
                     launchers.insert(i, os.path.split(dest_path)[1])
-            settings.set_strv("panel-launchers", launchers)
+            factory.settings.set_value("launcherList", launchers)
             if self.desktop_file is None:
                 self.ask_menu_launcher(dest_path)
         self.end()
